==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorTermFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class TopologySelectorTermFluentImpl<A extends io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<A>{
  public TopologySelectorTermFluentImpl() {
  }
  public TopologySelectorTermFluentImpl(io.fabric8.kubernetes.api.model.TopologySelectorTerm instance) {
    this.withMatchLabelExpressions(instance.getMatchLabelExpressions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> matchLabelExpressions =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").add(index >= 0 ? index : _visitables.get("matchLabelExpressions").size(), builder);this.matchLabelExpressions.add(index >= 0 ? index : matchLabelExpressions.size(), builder); return (A)this;
  }
  public A setToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);
    if (index < 0 || index >= _visitables.get("matchLabelExpressions").size()) { _visitables.get("matchLabelExpressions").add(builder); } else { _visitables.get("matchLabelExpressions").set(index, builder);}
    if (index < 0 || index >= matchLabelExpressions.size()) { matchLabelExpressions.add(builder); } else { matchLabelExpressions.set(index, builder);}
     return (A)this;
  }
  public A addToMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").add(builder);this.matchLabelExpressions.add(builder);} return (A)this;
  }
  public A addAllToMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").add(builder);this.matchLabelExpressions.add(builder);} return (A)this;
  }
  public A removeFromMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").remove(builder);if (this.matchLabelExpressions != null) {this.matchLabelExpressions.remove(builder);}} return (A)this;
  }
  public A removeAllFromMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").remove(builder);if (this.matchLabelExpressions != null) {this.matchLabelExpressions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromMatchLabelExpressions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    if (matchLabelExpressions == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> each = matchLabelExpressions.iterator();
    final List visitables = _visitables.get("matchLabelExpressions");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildMatchLabelExpressions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> getMatchLabelExpressions() {
    return build(matchLabelExpressions);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> buildMatchLabelExpressions() {
    return build(matchLabelExpressions);
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchLabelExpression(java.lang.Integer index) {
    return this.matchLabelExpressions.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildFirstMatchLabelExpression() {
    return this.matchLabelExpressions.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildLastMatchLabelExpression() {
    return this.matchLabelExpressions.get(matchLabelExpressions.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder item: matchLabelExpressions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder item: matchLabelExpressions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMatchLabelExpressions(java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> matchLabelExpressions) {
    if (this.matchLabelExpressions != null) { _visitables.get("matchLabelExpressions").removeAll(this.matchLabelExpressions);}
    if (matchLabelExpressions != null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>(); for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : matchLabelExpressions){this.addToMatchLabelExpressions(item);}} else { this.matchLabelExpressions = null;} return (A) this;
  }
  public A withMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... matchLabelExpressions) {
    if (this.matchLabelExpressions != null) {this.matchLabelExpressions.clear();}
    if (matchLabelExpressions != null) {for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item :matchLabelExpressions){ this.addToMatchLabelExpressions(item);}} return (A) this;
  }
  public java.lang.Boolean hasMatchLabelExpressions() {
    return matchLabelExpressions != null && !matchLabelExpressions.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpression() {
    return new io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl.MatchLabelExpressionsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpressionLike(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    return new io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl.MatchLabelExpressionsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> setNewMatchLabelExpressionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    return new io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl.MatchLabelExpressionsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchLabelExpression(java.lang.Integer index) {
    if (matchLabelExpressions.size() <= index) throw new RuntimeException("Can't edit matchLabelExpressions. Index exceeds size.");
    return setNewMatchLabelExpressionLike(index, buildMatchLabelExpression(index));
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editFirstMatchLabelExpression() {
    if (matchLabelExpressions.size() == 0) throw new RuntimeException("Can't edit first matchLabelExpressions. The list is empty.");
    return setNewMatchLabelExpressionLike(0, buildMatchLabelExpression(0));
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editLastMatchLabelExpression() {
    int index = matchLabelExpressions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last matchLabelExpressions. The list is empty.");
    return setNewMatchLabelExpressionLike(index, buildMatchLabelExpression(index));
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    int index = -1;
    for (int i=0;i<matchLabelExpressions.size();i++) { 
    if (predicate.test(matchLabelExpressions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching matchLabelExpressions. No match found.");
    return setNewMatchLabelExpressionLike(index, buildMatchLabelExpression(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TopologySelectorTermFluentImpl that = (TopologySelectorTermFluentImpl) o;
    if (matchLabelExpressions != null ? !matchLabelExpressions.equals(that.matchLabelExpressions) :that.matchLabelExpressions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchLabelExpressions,  additionalProperties,  super.hashCode());
  }
  public class MatchLabelExpressionsNestedImpl<N> extends io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementFluentImpl<io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<N>> implements io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MatchLabelExpressionsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(this, item);
    }
    MatchLabelExpressionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(this);
    }
    io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) TopologySelectorTermFluentImpl.this.setToMatchLabelExpressions(index,builder.build());
    }
    public N endMatchLabelExpression() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorTermFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class TopologySelectorTermFluentImpl<A extends io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<A>{
  public TopologySelectorTermFluentImpl() {
  }
  public TopologySelectorTermFluentImpl(io.fabric8.kubernetes.api.model.TopologySelectorTerm instance) {
    this.withMatchLabelExpressions(instance.getMatchLabelExpressions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> matchLabelExpressions =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").add(index >= 0 ? index : _visitables.get("matchLabelExpressions").size(), builder);this.matchLabelExpressions.add(index >= 0 ? index : matchLabelExpressions.size(), builder); return (A)this;
  }
  public A setToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);
    if (index < 0 || index >= _visitables.get("matchLabelExpressions").size()) { _visitables.get("matchLabelExpressions").add(builder); } else { _visitables.get("matchLabelExpressions").set(index, builder);}
    if (index < 0 || index >= matchLabelExpressions.size()) { matchLabelExpressions.add(builder); } else { matchLabelExpressions.set(index, builder);}
     return (A)this;
  }
  public A addToMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").add(builder);this.matchLabelExpressions.add(builder);} return (A)this;
  }
  public A addAllToMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items) {
    if (this.matchLabelExpressions == null) {this.matchLabelExpressions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder>();}
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").add(builder);this.matchLabelExpressions.add(builder);} return (A)this;
  }
  public A removeFromMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").remove(builder);if (this.matchLabelExpressions != null) {this.matchLabelExpressions.remove(builder);}} return (A)this;
  }
  public A removeAllFromMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : items) {io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(item);_visitables.get("matchLabelExpressions").remove(builder);if (this.matchLabelExpressions != null) {this.matchLabelExpressions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromMatchLabelExpressions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    if (matchLabelExpressions == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> each = matchLabelExpressions.iterator();
    final List visitables = _visitables.get("matchLabelExpressions");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildMatchLabelExpressions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> getMatchLabelExpressions() {
    return build(matchLabelExpressions);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> buildMatchLabelExpressions() {
    return build(matchLabelExpressions);
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchLabelExpression(java.lang.Integer index) {
    return this.matchLabelExpressions.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildFirstMatchLabelExpression() {
    return this.matchLabelExpressions.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildLastMatchLabelExpression() {
    return this.matchLabelExpressions.get(matchLabelExpressions.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder item: matchLabelExpressions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder item: matchLabelExpressions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMatchLabelExpressions(java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> matchLabelExpressions) {
    if (this.matchLabelExpressions != null) { _visitables.get("matchLabelExpressions").removeAll(this.matchLabelExpressions);}
    if (matchLabelExpressions != null) {this.matchLabelExpressions = new java.util.ArrayList(); for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item : matchLabelExpressions){this.addToMatchLabelExpressions(item);}} else { this.matchLabelExpressions = null;} return (A) this;
  }
  public A withMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... matchLabelExpressions) {
    if (this.matchLabelExpressions != null) {this.matchLabelExpressions.clear();}
    if (matchLabelExpressions != null) {for (io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item :matchLabelExpressions){ this.addToMatchLabelExpressions(item);}} return (A) this;
  }
  public java.lang.Boolean hasMatchLabelExpressions() {
    return matchLabelExpressions != null && !matchLabelExpressions.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpression() {
    return new io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl.MatchLabelExpressionsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpressionLike(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    return new io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl.MatchLabelExpressionsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> setNewMatchLabelExpressionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
    return new io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl.MatchLabelExpressionsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchLabelExpression(java.lang.Integer index) {
    if (matchLabelExpressions.size() <= index) throw new RuntimeException("Can't edit matchLabelExpressions. Index exceeds size.");
    return setNewMatchLabelExpressionLike(index, buildMatchLabelExpression(index));
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editFirstMatchLabelExpression() {
    if (matchLabelExpressions.size() == 0) throw new RuntimeException("Can't edit first matchLabelExpressions. The list is empty.");
    return setNewMatchLabelExpressionLike(0, buildMatchLabelExpression(0));
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editLastMatchLabelExpression() {
    int index = matchLabelExpressions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last matchLabelExpressions. The list is empty.");
    return setNewMatchLabelExpressionLike(index, buildMatchLabelExpression(index));
  }
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate) {
    int index = -1;
    for (int i=0;i<matchLabelExpressions.size();i++) { 
    if (predicate.test(matchLabelExpressions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching matchLabelExpressions. No match found.");
    return setNewMatchLabelExpressionLike(index, buildMatchLabelExpression(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TopologySelectorTermFluentImpl that = (TopologySelectorTermFluentImpl) o;
    if (matchLabelExpressions != null ? !matchLabelExpressions.equals(that.matchLabelExpressions) :that.matchLabelExpressions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchLabelExpressions,  additionalProperties,  super.hashCode());
  }
  public class MatchLabelExpressionsNestedImpl<N> extends io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementFluentImpl<io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<N>> implements io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MatchLabelExpressionsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(this, item);
    }
    MatchLabelExpressionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder(this);
    }
    io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) TopologySelectorTermFluentImpl.this.setToMatchLabelExpressions(index,builder.build());
    }
    public N endMatchLabelExpression() {
      return and();
    }
    
  }
  
}
